#content ul.scales {
    height: 550px;
    overflow-y: scroll;
}
#content ul.scales li {
    border: solid 1px #999;
    padding: 0.5em;
    margin: 0 1em 1em 0;
    cursor: pointer;
    opacity: 0.5;
}
#content ul.scales li.selected {
    border-color: #000;
    opacity: 1;
}
.thumbPreview {
    overflow:hidden;
}
.thumbPreview img {
    max-width:100%;
    height:auto;
}

#coords .jcrop-holder {
    margin-bottom:1em;
}

.croppingimagefield {
    padding-bottom: 1em;
}